@@ -99,11 +99,11 @@ int main (int argc, char **argv)
   char *coord_names[3], *qa_record[2][4], *info[3], *var_names[3];
   char *block_names[10], *nset_names[10], *sset_names[10];
   char *attrib_names[10];
-  char name[MAX_STR_LENGTH+1];
   char title[MAX_LINE_LENGTH+1], elem_type[MAX_STR_LENGTH+1];
   char title_chk[MAX_LINE_LENGTH+1];
   char *cdum = 0;
   char *prop_names[3];
+  char *name = NULL;
 
   CPU_word_size = 0;                    /* sizeof(float) */
   IO_word_size = 0;                     /* use what is stored in file */
@@ -137,12 +137,14 @@ int main (int argc, char **argv)
     int max_all_name_length = ex_inquire_int(exoid, EX_INQ_DB_MAX_ALLOWED_NAME_LENGTH);
     int max_use_name_length = ex_inquire_int(exoid, EX_INQ_DB_MAX_USED_NAME_LENGTH);
     printf ("This file can use at most %d-character names\n", max_all_name_length);
-    printf ("This maximum name length used is %d-character names\n", max_use_name_length);
+    printf ("The maximum name length used is %d-character names\n", max_use_name_length);
 
     max_name_length = max_use_name_length;
     ex_set_max_name_length(exoid, max_name_length);
   }
   
+  name = (char *) calloc(max_name_length+1, sizeof(char));
+  
   /* read database parameters */
   error = ex_get_init (exoid, title, &num_dim, &num_nodes, &num_elem,
                        &num_elem_blk, &num_node_sets, &num_side_sets);
@@ -160,6 +162,7 @@ int main (int argc, char **argv)
 
   /* Check that ex_inquire gives same title */
   error = ex_inquire (exoid, EX_INQ_TITLE, &idum, &fdum, title_chk);
+  printf ("after ex_inquire, error = %3d\n", error);
   if (strcmp(title, title_chk) != 0) {
     printf ("error in ex_inquire for EX_INQ_TITLE\n");
   }
@@ -231,6 +234,7 @@ int main (int argc, char **argv)
   {
     int num_attrs = 0;
     error = ex_get_attr_param(exoid, EX_NODAL, 0, &num_attrs);
+    printf (" after ex_get_attr_param, error = %d\n", error);
     printf ("num nodal attributes = %d\n", num_attrs);
     if (num_attrs > 0) {
       for (j=0; j<num_attrs; j++) {
@@ -244,6 +248,7 @@ int main (int argc, char **argv)
 	for (j=0; j<num_attrs; j++) {
 	  printf ("nodal attribute %d = '%s'\n", j, attrib_names[j]);
 	  error = ex_get_one_attr(exoid, EX_NODAL, 0, j+1, attrib);
+	  printf (" after ex_get_one_attr, error = %d\n", error);
 	  for (i=0; i < num_nodes; i++) {
 	    printf ("%5.1f\n", attrib[i]);
 	  }
@@ -468,6 +473,7 @@ int main (int argc, char **argv)
 	{
 	  int num_attrs = 0;
 	  error = ex_get_attr_param(exoid, EX_NODE_SET, ids[i], &num_attrs);
+	  printf (" after ex_get_attr_param, error = %d\n", error);
 	  printf ("num nodeset attributes for nodeset %d = %d\n", ids[i], num_attrs);
 	  if (num_attrs > 0) {
 	    for (j=0; j<num_attrs; j++) {
@@ -481,6 +487,7 @@ int main (int argc, char **argv)
 	      for (j=0; j<num_attrs; j++) {
 		printf ("nodeset attribute %d = '%s'\n", j, attrib_names[j]);
 		error = ex_get_one_attr(exoid, EX_NODE_SET, ids[i], j+1, attrib);
+		printf (" after ex_get_one_attr, error = %d\n", error);
 		for (k=0; k < num_nodes_in_set; k++) {
 		  printf ("%5.1f\n", attrib[k]);
 		}
@@ -1196,6 +1203,7 @@ int main (int argc, char **argv)
   if (num_node_sets > 0)
     free (num_nodes_per_set);
 
+  free (name);
   error = ex_close (exoid);
   printf ("\nafter ex_close, error = %3d\n", error);
   return 0;
