@@ -149,6 +149,7 @@ int main (int argc, char **argv)
 
   /* Check that ex_inquire gives same title */
   error = ex_inquire (exoid, EX_INQ_TITLE, &idum, &fdum, title_chk);
+  printf (" after ex_inquire, error = %d\n", error);
   if (strcmp(title, title_chk) != 0) {
     printf ("error in ex_inquire for EX_INQ_TITLE\n");
   }
@@ -156,7 +157,11 @@ int main (int argc, char **argv)
   /* read nodal coordinates values and names from database */
 
   x = (float *) calloc(num_nodes, sizeof(float));
-  y = (float *) calloc(num_nodes, sizeof(float));
+  if (num_dim >= 2)
+    y = (float *) calloc(num_nodes, sizeof(float));
+  else
+    y = 0;
+  
   if (num_dim >= 3)
     z = (float *) calloc(num_nodes, sizeof(float));
   else
@@ -171,12 +176,13 @@ int main (int argc, char **argv)
       printf ("%5.1f\n", x[i]);
     }
 
-  printf ("y coords = \n");
-  for (i=0; i<num_nodes; i++)
-    {
-      printf ("%5.1f\n", y[i]);
-    }
-
+  if (num_dim >= 2) {
+    printf ("y coords = \n");
+    for (i=0; i<num_nodes; i++)
+      {
+	printf ("%5.1f\n", y[i]);
+      }
+  }
   if (num_dim >= 3)
     {
       printf ("z coords = \n");
@@ -197,7 +203,8 @@ int main (int argc, char **argv)
     printf ("%f \n", y[0]);
   */
   free (x);
-  free (y);
+  if (num_dim >= 2)
+    free (y);
   if (num_dim >= 3)
     free (z);
 
@@ -210,7 +217,8 @@ int main (int argc, char **argv)
   error = ex_get_coord_names (exoid, coord_names);
   printf ("\nafter ex_get_coord_names, error = %3d\n", error);
   printf ("x coord name = '%s'\n", coord_names[0]);
-  printf ("y coord name = '%s'\n", coord_names[1]);
+  if (num_dim >1)
+    printf ("y coord name = '%s'\n", coord_names[1]);
   if (num_dim >2)
     printf ("z coord name = '%s'\n", coord_names[2]);
 
@@ -220,6 +228,7 @@ int main (int argc, char **argv)
   {
     int num_attrs = 0;
     error = ex_get_attr_param(exoid, EX_NODAL, 0, &num_attrs);
+    printf (" after ex_get_attr_param, error = %d\n", error);
     printf ("num nodal attributes = %d\n", num_attrs);
     if (num_attrs > 0) {
       for (j=0; j<num_attrs; j++) {
@@ -233,6 +242,7 @@ int main (int argc, char **argv)
 	for (j=0; j<num_attrs; j++) {
 	  printf ("nodal attribute %d = '%s'\n", j, attrib_names[j]);
 	  error = ex_get_one_attr(exoid, EX_NODAL, 0, j+1, attrib);
+	  printf (" after ex_get_one_attr, error = %d\n", error);
 	  for (i=0; i < num_nodes; i++) {
 	    printf ("%5.1f\n", attrib[i]);
 	  }
@@ -457,6 +467,7 @@ int main (int argc, char **argv)
 	{
 	  int num_attrs = 0;
 	  error = ex_get_attr_param(exoid, EX_NODE_SET, ids[i], &num_attrs);
+	  printf (" after ex_get_attr_param, error = %d\n", error);
 	  printf ("num nodeset attributes for nodeset %d = %d\n", ids[i], num_attrs);
 	  if (num_attrs > 0) {
 	    for (j=0; j<num_attrs; j++) {
@@ -470,6 +481,7 @@ int main (int argc, char **argv)
 	      for (j=0; j<num_attrs; j++) {
 		printf ("nodeset attribute %d = '%s'\n", j, attrib_names[j]);
 		error = ex_get_one_attr(exoid, EX_NODE_SET, ids[i], j+1, attrib);
+		printf (" after ex_get_one_attr, error = %d\n", error);
 		for (k=0; k < num_nodes_in_set; k++) {
 		  printf ("%5.1f\n", attrib[k]);
 		}
