@@ -279,6 +279,8 @@ int main (int argc, char **argv)
    ebids[5] = 15;
    ebids[6] = 16;
 
+   error = ex_put_name(exoid, EX_ELEM_BLOCK, ebids[0], block_names[0]);
+
    error = ex_put_elem_block (exoid, ebids[0], "quad", num_elem_in_block[0],
                               num_nodes_per_elem[0], 1);
    printf ("after ex_put_elem_block, error = %d\n", error);
@@ -343,8 +345,10 @@ int main (int argc, char **argv)
    }
 
    /* Write element block names */
-   error = ex_put_names(exoid, EX_ELEM_BLOCK, block_names);
-   printf ("after ex_put_names, error = %d\n", error);
+   for (i=0; i < 7; i++) {
+     error = ex_put_name(exoid, EX_ELEM_BLOCK, ebids[i], block_names[i]);
+     printf ("after ex_put_names, error = %d\n", error);
+   }
 
    if (error) {
      ex_close (exoid);
@@ -586,8 +590,8 @@ int main (int argc, char **argv)
      exit(-1);
    }
 
-   node_list[0] = 100; node_list[1] = 101; node_list[2] = 102; 
-   node_list[3] = 103; node_list[4] = 104; 
+   node_list[0] = 10; node_list[1] = 11; node_list[2] = 12; 
+   node_list[3] = 13; node_list[4] = 14; 
 
    dist_fact[0] = 1.0; dist_fact[1] = 2.0; dist_fact[2] = 3.0;
    dist_fact[3] = 4.0; dist_fact[4] = 5.0;
@@ -615,7 +619,7 @@ int main (int argc, char **argv)
      exit(-1);
    }
 
-   node_list[0] = 200; node_list[1] = 201; node_list[2] = 202; 
+   node_list[0] = 20; node_list[1] = 21; node_list[2] = 22; 
 
    dist_fact[0] = 1.1; dist_fact[1] = 2.1; dist_fact[2] = 3.1;
 
