@@ -461,8 +461,8 @@ int main (int argc, char **argv)
    error = ex_put_node_set_param (exoid, 20, 5, 5);
    printf ("after ex_put_node_set_param, error = %d\n", error);
 
-   node_list[0] = 100; node_list[1] = 101; node_list[2] = 102; 
-   node_list[3] = 103; node_list[4] = 104; 
+   node_list[0] = 10; node_list[1] = 11; node_list[2] = 12; 
+   node_list[3] = 13; node_list[4] = 14; 
 
    dist_fact[0] = 1.0; dist_fact[1] = 2.0; dist_fact[2] = 3.0;
    dist_fact[3] = 4.0; dist_fact[4] = 5.0;
@@ -475,7 +475,7 @@ int main (int argc, char **argv)
    error = ex_put_node_set_param (exoid, 21, 3, 3);
    printf ("after ex_put_node_set_param, error = %d\n", error);
 
-   node_list[0] = 200; node_list[1] = 201; node_list[2] = 202; 
+   node_list[0] = 20; node_list[1] = 21; node_list[2] = 22; 
 
    dist_fact[0] = 1.1; dist_fact[1] = 2.1; dist_fact[2] = 3.1;
 
@@ -500,8 +500,8 @@ int main (int argc, char **argv)
    error = ex_put_node_set_param (exoid2, 20, 5, 5);
    printf ("after ex_put_node_set_param (2), error = %d\n", error);
 
-   node_list2[0] = 100; node_list2[1] = 101; node_list2[2] = 102; 
-   node_list2[3] = 103; node_list2[4] = 104; 
+   node_list2[0] = 10; node_list2[1] = 11; node_list2[2] = 12; 
+   node_list2[3] = 13; node_list2[4] = 14; 
 
    dist_fact2[0] = 1.0; dist_fact2[1] = 2.0; dist_fact2[2] = 3.0;
    dist_fact2[3] = 4.0; dist_fact2[4] = 5.0;
@@ -514,7 +514,7 @@ int main (int argc, char **argv)
    error = ex_put_node_set_param (exoid2, 21, 3, 3);
    printf ("after ex_put_node_set_param (2), error = %d\n", error);
 
-   node_list2[0] = 200; node_list2[1] = 201; node_list2[2] = 202; 
+   node_list2[0] = 20; node_list2[1] = 21; node_list2[2] = 22; 
 
    dist_fact2[0] = 1.1; dist_fact2[1] = 2.1; dist_fact2[2] = 3.1;
 
@@ -546,9 +546,9 @@ int main (int argc, char **argv)
 
    node_ind[0] = 0; node_ind[1] = 5;
 
-   node_list[0] = 100; node_list[1] = 101; node_list[2] = 102; 
-   node_list[3] = 103; node_list[4] = 104; 
-   node_list[5] = 200; node_list[6] = 201; node_list[7] = 202;
+   node_list[0] = 10; node_list[1] = 11; node_list[2] = 12; 
+   node_list[3] = 13; node_list[4] = 14; 
+   node_list[5] = 20; node_list[6] = 21; node_list[7] = 22;
 
    num_df_per_set[0] = 5; num_df_per_set[1] = 3;
 
@@ -558,44 +558,25 @@ int main (int argc, char **argv)
    dist_fact[3] = 4.0; dist_fact[4] = 5.0; 
    dist_fact[5] = 1.1; dist_fact[6] = 2.1; dist_fact[7] = 3.1;
 
+   prop_array[0] = 1000;
+   prop_array[1] = 2000;
+
    error = ex_put_concat_node_sets (exoid, ids, num_nodes_per_set,
                                     num_df_per_set, node_ind,
                                     df_ind, node_list, dist_fact);
    printf ("after ex_put_concat_node_sets, error = %d\n", error);
 
-
    error = ex_put_prop(exoid, EX_NODE_SET, 20, "FACE", 4);
    printf ("after ex_put_prop, error = %d\n", error);
    error = ex_put_prop(exoid, EX_NODE_SET, 21, "FACE", 5);
    printf ("after ex_put_prop, error = %d\n", error);
 
-   prop_array[0] = 1000;
-   prop_array[1] = 2000;
-
    error = ex_put_prop_array(exoid, EX_NODE_SET, "VELOCITY", prop_array);
    printf ("after ex_put_prop_array, error = %d\n", error);
 
-   ids2[0] = 20; ids2[1] = 21;
-
-   num_nodes_per_set2[0] = 5; num_nodes_per_set2[1] = 3;
-
-   node_ind2[0] = 0; node_ind2[1] = 5;
-
-   node_list2[0] = 100; node_list2[1] = 101; node_list2[2] = 102; 
-   node_list2[3] = 103; node_list2[4] = 104; 
-   node_list2[5] = 200; node_list2[6] = 201; node_list2[7] = 202;
-
-   num_df_per_set2[0] = 5; num_df_per_set2[1] = 3;
-
-   df_ind2[0] = 0; df_ind2[1] = 5;
-
-   dist_fact2[0] = 1.0; dist_fact2[1] = 2.0; dist_fact2[2] = 3.0; 
-   dist_fact2[3] = 4.0; dist_fact2[4] = 5.0; 
-   dist_fact2[5] = 1.1; dist_fact2[6] = 2.1; dist_fact2[7] = 3.1;
-
-   error = ex_put_concat_node_sets (exoid2, ids2, num_nodes_per_set2,
-                                    num_df_per_set2, node_ind2,
-                                    df_ind2, node_list2, dist_fact2);
+   error = ex_put_concat_node_sets (exoid2, ids, num_nodes_per_set,
+                                    num_df_per_set, node_ind,
+                                    df_ind, node_list, dist_fact);
    printf ("after ex_put_concat_node_sets, error = %d\n", error);
 
 
@@ -604,11 +585,9 @@ int main (int argc, char **argv)
    error = ex_put_prop(exoid2, EX_NODE_SET, 21, "FACE", 5);
    printf ("after ex_put_prop, error = %d\n", error);
 
-   prop_array2[0] = 1000;
-   prop_array2[1] = 2000;
-
-   error = ex_put_prop_array(exoid2, EX_NODE_SET, "VELOCITY", prop_array2);
+   error = ex_put_prop_array(exoid2, EX_NODE_SET, "VELOCITY", prop_array);
    printf ("after ex_put_prop_array, error = %d\n", error);
+
 #endif /* EX_TEST_INDIV_NODESET */
 
 #ifdef EX_TEST_INDIV_SIDESET
