@@ -85,7 +85,7 @@ int main (int argc, char **argv)
   char *prop_names[2];
   char *eb_type[10];
    
-  ex_opts (EX_VERBOSE || EX_ABORT);
+  ex_opts (EX_VERBOSE|EX_ABORT);
 
   /* Specify compute and i/o word size */
 
@@ -476,8 +476,8 @@ int main (int argc, char **argv)
     exit(-1);
   }
 
-  node_list[0] = 100; node_list[1] = 101; node_list[2] = 102; 
-  node_list[3] = 103; node_list[4] = 104; 
+  node_list[0] = 10; node_list[1] = 11; node_list[2] = 12; 
+  node_list[3] = 13; node_list[4] = 14; 
 
   dist_fact[0] = 1.0; dist_fact[1] = 2.0; dist_fact[2] = 3.0;
   dist_fact[3] = 4.0; dist_fact[4] = 5.0;
@@ -496,7 +496,7 @@ int main (int argc, char **argv)
     exit(-1);
   }
 
-  node_list[0] = 200; node_list[1] = 201; node_list[2] = 202; 
+  node_list[0] = 20; node_list[1] = 21; node_list[2] = 22; 
 
   dist_fact[0] = 1.1; dist_fact[1] = 2.1; dist_fact[2] = 3.1;
 
