@@ -80,7 +80,7 @@ int main (int argc, char **argv)
    float dist_fact[100];
    char *coord_names[3], *qa_record[2][4], *info[3];
 
-   ex_opts (EX_VERBOSE || EX_ABORT); 
+   ex_opts (EX_VERBOSE|EX_ABORT); 
 
 /* Specify compute and i/o word size */
 
